@@ -1,7 +1,7 @@
 package App::sshwrap::hostcolor;
 
 our $DATE = '2018-09-26'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -71,7 +71,7 @@ App::sshwrap::hostcolor - SSH wrapper script to remember the terminal background
 
 =head1 VERSION
 
-This document describes version 0.004 of App::sshwrap::hostcolor (from Perl distribution App-sshwrap-hostcolor), released on 2018-09-26.
+This document describes version 0.005 of App::sshwrap::hostcolor (from Perl distribution App-sshwrap-hostcolor), released on 2018-09-26.
 
 =head1 SYNOPSIS
 
@@ -95,14 +95,6 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-B<ssh>
-
-Some video demonstrations: L<one|https://www.youtube.com/watch?v=Upz1ZtiJk1Y>,
-L<two|https://www.youtube.com/watch?v=IyJKea6Sv8U>,
-L<three|https://www.youtube.com/watch?v=Upz1ZtiJk1Y>.
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
